@@ -4,4 +4,4 @@ from dotenv import load_dotenv
 load_dotenv()
 
 api_key = os.getenv("VOCODE_API_KEY")
-BASE_URL = "api.vocode.dev"
\ No newline at end of file
+BASE_URL = "napi.vocode.dev"
\ No newline at end of file
